@@ -1,21 +1,16 @@
-/* Copyright (C) 2003 artofcode LLC.  All rights reserved.
-  
-  This software is provided AS-IS with no warranty, either express or
-  implied.
-  
-  This software is distributed under license and may not be copied,
-  modified or distributed except as expressly authorized under the terms
-  of the license contained in the file LICENSE in this distribution.
-  
-  For more information about licensing, please refer to
-  http://www.ghostscript.com/licensing/. For information on
-  commercial licensing, go to http://www.artifex.com/licensing/ or
-  contact Artifex Software, Inc., 101 Lucas Valley Road #110,
-  San Rafael, CA  94903, U.S.A., +1(415)492-9861.
+/* Portions Copyright (C) 2001, 2004 artofcode LLC.
+   Portions Copyright (C) 1996, 2001 Artifex Software Inc.
+   Portions Copyright (C) 1988, 2000 Aladdin Enterprises.
+   This software is based in part on the work of the Independent JPEG Group.
+   All Rights Reserved.
 
-*/
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/ or
+   contact Artifex Software, Inc., 101 Lucas Valley Road #110,
+   San Rafael, CA  94903, (415)492-9861, for further information. */
 
-/* $Id: dmmain.c,v 1.1 2004/01/13 22:33:45 henrys Exp $ */
+/* $Id: dmmain.c,v 1.2 2005/02/21 21:25:01 stefan Exp $ */
 
 /* Ghostscript shlib example wrapper for Macintosh (Classic/Carbon) contributed
    by Nigel Hathaway. Uses the Metrowerks CodeWarrior SIOUX command-line library.
