@@ -10,7 +10,7 @@
    contact Artifex Software, Inc., 101 Lucas Valley Road #110,
    San Rafael, CA  94903, (415)492-9861, for further information. */
 
-/*$RCSfile: gdevprn.c,v $ $Revision: 1.22 $ */
+/*$RCSfile: gdevprn.c,v $ $Revision: 1.25 $ */
 /* Generic printer driver support */
 #include "ctype_.h"
 #include "gdevprn.h"
@@ -111,7 +111,7 @@ gdev_prn_setup_as_command_list(gx_device *pdev, gs_memory_t *buffer_memory,
     for (; fp_ && (fp_[1] & 0xff000000) == 0x08000000; fp_ = (ulong *)*fp_)\
 	dprintf2("  fp=0x%lx ip=0x%lx\n", (ulong)fp_, fp_[1]);\
   END
-dputs("alloc buffer:\n");
+    dputs(pdev->memory, "alloc buffer:\n");
 BACKTRACE(pdev);
 #endif /*DEBUGGING_HACKS*/
     for ( space = space_params->BufferSpace; ; ) {
@@ -944,6 +944,13 @@ gdev_create_buf_device(create_buf_device_proc_t cbd_proc, gx_device **pbdev,
 	return code;
     /* Retain this device -- it will be freed explicitly. */
     gx_device_retain(*pbdev, true);
+    /* a not-so-obvious check if this is a plane extraction device */
+    if (!gs_device_is_memory(*pbdev))
+	/* Like the buffer device the plane device is freed explicitly
+           so it also needs to be retained, see
+           gx_default_destroy_buf_device */
+	gx_device_retain(((gx_device_plane_extract *)*pbdev)->plane_dev, true);
+
     return code;
 }
 
@@ -1047,7 +1054,16 @@ gx_default_setup_buf_device(gx_device *bdev, byte *buffer, int bytes_per_line,
     /****** HACK ******/
     if ((gx_device *)mdev == bdev && mdev->num_planes)
 	raster = bitmap_raster(mdev->planes[0].depth * mdev->width);
+
+    if (ptrs == 0 && mdev->line_ptrs) {
+        /* HACK covers up miss use of interface,
+	 * when mdev->line_ptrs are to be reused caller should set ptrs = line_ptrs
+	 * otherwise the line_ptrs will be reallocated causing a leak.
+	 */
+	ptrs = mdev->line_ptrs;
+    }
     if (ptrs == 0) {
+
 	/*
 	 * Allocate line pointers now; free them when we close the device.
 	 * Note that for multi-planar devices, we have to allocate using
