@@ -10,7 +10,7 @@
    contact Artifex Software, Inc., 101 Lucas Valley Road #110,
    San Rafael, CA  94903, (415)492-9861, for further information. */
 
-/*$RCSfile: gsstate.c,v $ $Revision: 1.22 $ */
+/*$RCSfile: gsstate.c,v $ $Revision: 1.23 $ */
 /* Miscellaneous graphics state operators for Ghostscript library */
 #include "gx.h"
 #include "memory_.h"
@@ -237,8 +237,6 @@ gs_state_alloc(gs_memory_t * mem)
 
     /* Initialize other things not covered by initgraphics */
 
-    pgs->path = gx_path_alloc(gstate_path_memory(mem), "gs_state_alloc(path)");
-    pgs->clip_path = gx_cpath_alloc(mem, "gs_state_alloc(clip_path)");
     pgs->clip_stack = 0;
     pgs->view_clip = gx_cpath_alloc(mem, "gs_state_alloc(view_clip)");
     pgs->view_clip->rule = 0;	/* no clipping */
@@ -274,6 +272,15 @@ fail:
     return 0;
 }
 
+void
+gs_state_free_view_clip(gs_state *pgs)
+{
+    if (pgs->view_clip) {
+        gx_cpath_free(pgs->view_clip, "gs_state_free_view_clip(view_clip)");
+        pgs->view_clip = 0;
+    }
+}
+
 /* Set the client data in a graphics state. */
 /* This should only be done to a newly created state. */
 void
