@@ -10,7 +10,7 @@
    contact Artifex Software, Inc., 101 Lucas Valley Road #110,
    San Rafael, CA  94903, (415)492-9861, for further information. */
 
-/*$RCSfile: gxclrast.c,v $ $Revision: 1.22 $ */
+/*$RCSfile: gxclrast.c,v $ $Revision: 1.23 $ */
 /* Command list interpreter/rasterizer */
 #include "memory_.h"
 #include "gx.h"
@@ -1505,6 +1505,11 @@ idata:			data_size = 0;
     ht_buff.ht_size = 0;
     ht_buff.read_size = 0;
 
+    if (color_space.params.indexed.lookup.table.size)
+        gs_free_const_string(mem,
+			     color_space.params.indexed.lookup.table.data,
+			     color_space.params.indexed.lookup.table.size,
+			     "color_space indexed table");
     gx_cpath_free(&clip_path, "clist_render_band exit");
     gx_path_free(&path, "clist_render_band exit");
     gs_imager_state_release(&imager_state);
@@ -1890,9 +1895,9 @@ read_set_color_space(command_buf_t *pcb, gs_imager_state *pis,
     } else {
 	if (pcolor_space->params.indexed.lookup.table.size)
 	    gs_free_const_string(mem,
-			pcolor_space->params.indexed.lookup.table.data,
-			pcolor_space->params.indexed.lookup.table.size,
-				 "old indexed table");
+				 pcolor_space->params.indexed.lookup.table.data,
+				 pcolor_space->params.indexed.lookup.table.size,
+				 "color_spapce indexed table");
 	pcolor_space->params.indexed.lookup.table.size = 0;
     }
     if (b & 8) {
@@ -1913,9 +1918,9 @@ read_set_color_space(command_buf_t *pcb, gs_imager_state *pis,
 	    map->proc.lookup_index = lookup_indexed_map;
 	    pcolor_space->params.indexed.lookup.map = map;
 	    data = (byte *)map->values;
-	    data_size = num_values * sizeof(map->values[0]);
+	    data_size = num_values * sizeof(map->values[0]);	
 	} else {
-	    byte *table = gs_alloc_string(mem, num_values, "indexed table");
+	    byte *table = gs_alloc_string(mem, num_values, "color_space indexed table");
 
 	    if (table == 0) {
 		code = gs_note_error(mem, gs_error_VMerror);
