@@ -1,20 +1,16 @@
-/* Copyright (C) 1989-2003 artofcode LLC.  All rights reserved.
-  
-  This software is provided AS-IS with no warranty, either express or
-  implied.
-  
-  This software is distributed under license and may not be copied,
-  modified or distributed except as expressly authorized under the terms
-  of the license contained in the file LICENSE in this distribution.
-  
-  For more information about licensing, please refer to
-  http://www.ghostscript.com/licensing/. For information on
-  commercial licensing, go to http://www.artifex.com/licensing/ or
-  contact Artifex Software, Inc., 101 Lucas Valley Road #110,
-  San Rafael, CA  94903, U.S.A., +1(415)492-9861.
-*/
+/* Portions Copyright (C) 2001, 2004 artofcode LLC.
+   Portions Copyright (C) 1996, 2001 Artifex Software Inc.
+   Portions Copyright (C) 1988, 2000 Aladdin Enterprises.
+   This software is based in part on the work of the Independent JPEG Group.
+   All Rights Reserved.
 
-/* $Id: gxfdrop.c,v 1.1 2004/01/13 22:33:48 henrys Exp $ */
+   This software is distributed under license and may not be copied, modified
+   or distributed except as expressly authorized under the terms of that
+   license.  Refer to licensing information at http://www.artifex.com/ or
+   contact Artifex Software, Inc., 101 Lucas Valley Road #110,
+   San Rafael, CA  94903, (415)492-9861, for further information. */
+
+/* $Id: gxfdrop.c,v 1.3 2005/02/22 18:04:05 stefan Exp $ */
 /* Dropout prevention for a character rasterization. */
 
 #include <assert.h>
@@ -106,7 +102,7 @@ private int store_margin(line_list * ll, margin_set * set, int ii0, int ii1)
     int i0 = ii0, i1 = ii1;
     margin *m0 = set->margin_touched, *m1;
 
-    assert(ii0 >= 0 && ii1 <= ll->bbox_width);
+    assert(ii0 >= 0);     /* assert(ii1 <= ll->bbox_width); */
     set->margin_touched = 0; /* safety */
     /* Find contacting elements. */
     if (m0 != 0) {
@@ -490,7 +486,7 @@ private int fill_margin(gx_device * dev, line_list * ll, margin_set *ms, int i0,
     gs_logical_operation_t lop = ll->lop;
     bool fill_direct = ll->fill_direct;
 
-    assert(i0 >= 0 && i1 <= ll->bbox_width);
+    assert(i0 >= 0); /* assert(i1 <= ll->bbox_width); */
     ir = i0;
     for (i = i0; i < i1; i++) {
 	int y0 = sect[i].y0, y1 = sect[i].y1, hh;
