@@ -10,7 +10,7 @@
    contact Artifex Software, Inc., 101 Lucas Valley Road #110,
    San Rafael, CA  94903, (415)492-9861, for further information. */
 
-/*$RCSfile: gxpflat.c,v $ $Revision: 1.10 $ */
+/*$RCSfile: gxpflat.c,v $ $Revision: 1.11 $ */
 /* Path flattening algorithms */
 #include "gx.h"
 #include "gxarith.h"
@@ -827,8 +827,11 @@ gx_flattened_iterator__switch_to_backscan2(gx_flattened_iterator *this,
 	}
 #   else
 	gx_flattened_iterator__switch_to_backscan1(this);
-	if (!last_segment)
-	    assert(gx_flattened_iterator__prev_filtered2_aux(this));
+	if (!last_segment) {
+	    int foo;
+	    foo = gx_flattened_iterator__prev_filtered2_aux(this);
+	    assert(foo);
+	}
 	gx_flattened_iterator__prev_filtered2_aux(this);
 #   endif
 }
