@@ -10,7 +10,7 @@
    contact Artifex Software, Inc., 101 Lucas Valley Road #110,
    San Rafael, CA  94903, (415)492-9861, for further information. */
 
-/*$RCSfile: iref.h,v $ $Revision: 1.10 $ */
+/*$RCSfile: iref.h,v $ $Revision: 1.11 $ */
 /* Object structure and type definitions for Ghostscript */
 
 #ifndef iref_INCLUDED
@@ -403,6 +403,10 @@ struct ref_s {
 	struct gx_device_s *pdevice;
 	obj_header_t *pstruct;
     } value;
+#ifdef GS_DEBUGGER
+    unsigned long offset;
+    unsigned long pfile;
+#endif
 };
 
 /* ---------------- Private ref macros ---------------- */
