@@ -9,7 +9,7 @@
    license.  Refer to licensing information at http://www.artifex.com/ or
    contact Artifex Software, Inc., 101 Lucas Valley Road #110,
    San Rafael, CA  94903, (415)492-9861, for further information. */
-/*$Id: pcfont.c,v 1.35 2003/11/01 18:53:37 henrys Exp $ */
+/*$Id: pcfont.c,v 1.38 2005/02/08 18:59:53 henrys Exp $ */
 
 /* pcfont.c */
 /* PCL5 font selection and text printing commands */
@@ -298,10 +298,23 @@ pcl_secondary_font_selection_id(pcl_args_t *pargs, pcl_state_t *pcs)
 
 private int
 pcl_select_default_font(pcl_args_t *pargs, pcl_state_t *pcs, int set)
-{	if ( int_arg(pargs) != 3 )
-	  return e_Range;
-	pcl_decache_font(pcs, set);
-	return e_Unimplemented;
+{	
+    if ( int_arg(pargs) != 3 )
+	return e_Range;
+
+    pcs->font_selection[set].params.proportional_spacing = false;
+    pcs->font_selection[set].params.symbol_set = pcs->default_symbol_set_value;
+    pl_fp_set_pitch_per_inch(&pcs->font_selection[set].params,
+			     pjl_proc_vartof(pcs->pjls, pjl_proc_get_envvar(pcs->pjls, "pitch")));
+    pcs->font_selection[set].params.height_4ths =
+	pjl_proc_vartof(pcs->pjls, pjl_proc_get_envvar(pcs->pjls, "ptsize")) * 4.0;
+
+    pcs->font_selection[set].params.style = 0;
+    pcs->font_selection[set].params.stroke_weight = 0;
+    pcs->font_selection[set].params.typeface_family = 3;	/* courier */
+    pcs->font_selection[set].font = 0;			/* not looked up yet */
+    pcl_decache_font(pcs, set);
+    return e_Unimplemented;
 }
 private int /* ESC ( 3 @ */
 pcl_select_default_font_primary(pcl_args_t *pargs, pcl_state_t *pcs)
@@ -590,7 +603,7 @@ pcl_set_current_font_environment(pcl_state_t *pcs)
 }
 
 private bool
-purge_all(cached_char * cc, void *dummy)
+purge_all(const gs_memory_t *mem, cached_char * cc, void *dummy)
 {
     return true;
 }
@@ -646,21 +659,28 @@ pcfont_do_reset(pcl_state_t *pcs, pcl_reset_type_t type)
 	gx_purge_selected_cached_chars(pcs->font_dir,
 				       purge_all,
 				       (void *)NULL);
+        /* free character cache machinery */
         gs_free_object(pcs->memory, pcs->font_dir->fmcache.mdata, "pcsfont_do_reset");
-        /* free the blasted chunks */
         {
+            /* free the circular list of memory chunks first */
             gx_bits_cache_chunk *chunk = pcs->font_dir->ccache.chunks;
-            gx_bits_cache_chunk *tmp_chunk = chunk;
-	    while( pcs->font_dir->ccache.chunks != chunk->next ) {
-	        tmp_chunk = chunk->next;
-		gs_free_object(pcs->memory, chunk->data, "pcfont_do_reset");
-		gs_free_object(pcs->memory, chunk, "pcfont_do_reset");
-		chunk = tmp_chunk;
-	    }
-	    gs_free_object(pcs->memory, chunk, "pcfont_do_reset");
+            gx_bits_cache_chunk *start_chunk = chunk;
+            gx_bits_cache_chunk *prev_chunk;
+            while (1) {
+                if (start_chunk == chunk->next) {
+                    gs_free_object(pcs->memory, chunk->data, "pcsfont_do_reset");
+                    gs_free_object(pcs->memory, chunk, "pcsfont_do_reset");
+                    break;
+                }
+                prev_chunk = chunk;
+                chunk = chunk->next;
+                gs_free_object(pcs->memory, prev_chunk->data, "pcsfont_do_reset");
+                gs_free_object(pcs->memory, prev_chunk, "pcsfont_do_reset");
+            }
+
+            gs_free_object(pcs->memory, pcs->font_dir->ccache.table, "pcfont_do_reset");
+            gs_free_object(pcs->memory, pcs->font_dir, "pcfont_do_reset");
         }
-        gs_free_object(pcs->memory, pcs->font_dir->ccache.table, "pcfont_do_reset");
-	gs_free_object(pcs->memory, pcs->font_dir, "pcfont_do_reset");
     }
 }
 
