@@ -9,7 +9,7 @@
    license.  Refer to licensing information at http://www.artifex.com/ or
    contact Artifex Software, Inc., 101 Lucas Valley Road #110,
    San Rafael, CA  94903, (415)492-9861, for further information. */
-/*$Id: pcpage.c,v 1.52 2003/09/06 17:11:03 stefan Exp $ */
+/*$Id: pcpage.c,v 1.54 2004/10/13 19:46:23 stefan Exp $ */
 
 /* pcpage.c - PCL5 page and transformation control commands */
 
@@ -385,10 +385,11 @@ new_logical_page(
 )
 {
     pcl_xfm_state_t *           pxfmst = &(pcs->xfm_state);
-
-    pcs->hmi_cp = HMI_DEFAULT;
-    pcs->vmi_cp = VMI_DEFAULT;
-
+    
+    if (reset_initial) {
+	pcs->hmi_cp = HMI_DEFAULT;
+	pcs->vmi_cp = VMI_DEFAULT;
+    }
     pxfmst->lp_orient = lp_orient;
     pxfmst->print_dir = 0;
     new_page_size(pcs, psize, reset_initial);
@@ -718,8 +719,17 @@ set_print_direction(
     uint            i = uint_arg(pargs);
 
     if ((i <= 270) && (i % 90 == 0)) {
-        pcs->xfm_state.print_dir = i / 90;
-        update_xfm_state(pcs, 0);
+	i /= 90;
+	if (i !=  pcs->xfm_state.print_dir) {
+	    pcl_break_underline(pcs); 
+	    pcs->xfm_state.print_dir = i;
+	    update_xfm_state(pcs, 0);
+	    pcl_continue_underline(pcs); 
+	}
+	else {
+	    pcs->xfm_state.print_dir = i;
+	    update_xfm_state(pcs, 0);
+	}
     }
     return 0;
 }
