@@ -9,7 +9,7 @@
    license.  Refer to licensing information at http://www.artifex.com/ or
    contact Artifex Software, Inc., 101 Lucas Valley Road #110,
    San Rafael, CA  94903, (415)492-9861, for further information. */
-/*$Id: pcparse.c,v 1.16 2003/09/06 17:11:03 stefan Exp $ */
+/*$Id: pcparse.c,v 1.17 2004/12/30 20:12:19 henrys Exp $ */
 
 /* pcparse.c */
 /* PCL5 parser */
@@ -42,7 +42,7 @@ pcl_register_command(byte *pindex, const pcl_command_definition_t *pcmd,
 	else if ( index != 0 && pcl_parser_state->definitions->pcl_command_list[index] == pcmd )
 	  ;
 	else
-	  pcl_parser_state->definitions->pcl_command_list[pcl_parser_state->definitions->pcl_command_next_index = ++index] = pcmd;
+            pcl_parser_state->definitions->pcl_command_list[pcl_parser_state->definitions->pcl_command_next_index = ++index] = (pcl_command_definition_t *)pcmd;
 	*pindex = index;
 	return (prev != 0 && prev != index);
 }
