@@ -9,7 +9,7 @@
    license.  Refer to licensing information at http://www.artifex.com/ or
    contact Artifex Software, Inc., 101 Lucas Valley Road #110,
    San Rafael, CA  94903, (415)492-9861, for further information. */
-/*$Id: pcpatrn.c,v 1.30 2003/10/02 06:15:32 henrys Exp $ */
+/*$Id: pcpatrn.c,v 1.34 2005/02/23 17:59:05 stefan Exp $ */
 
 /* pcpatrn.c - code for PCL and GL/2 patterns, including color */
 
@@ -17,6 +17,8 @@
 #include "gsuid.h"
 #include "gsmatrix.h"
 #include "gspcolor.h"
+#include "gxdcolor.h"
+#include "gxpcolor.h"
 #include "pccid.h"
 #include "pcfont.h"
 #include "pcpalet.h"
@@ -1388,12 +1390,6 @@ pattern_do_registration(
  
 }
 
-private bool
-pcl_pcache_remove_all_proc(gx_color_tile * ctile, void *proc_data)
-{
-    return true;
-}
-
   private void
 pattern_do_reset(
     pcl_state_t *       pcs,
@@ -1415,10 +1411,23 @@ pattern_do_reset(
         pcs->current_pattern_id = 0;
         pcs->pattern_type = pcl_pattern_solid_frgrnd;
     }
-    if ( type & pcl_reset_permanent || type & pcl_reset_printer )
-        gx_pattern_cache_winnow(gstate_pattern_cache(pcs->pgs),
-                                pcl_pcache_remove_all_proc,
-				NULL);
+    if ( type & pcl_reset_permanent || type & pcl_reset_printer ) {
+        if (gstate_pattern_cache(pcs->pgs)) {
+            gs_state *pgs = pcs->pgs;
+
+            (gstate_pattern_cache(pgs)->free_all)(gstate_pattern_cache(pgs));
+            gs_free_object(pcs->memory, 
+                           gstate_pattern_cache(pgs)->tiles, 
+                           "pattern_do_reset(tiles)");
+            gs_free_object(pcs->memory, 
+                           gstate_pattern_cache(pgs), 
+                           "pattern_do_reset(struct)");
+            while (pgs) {
+                gstate_set_pattern_cache(pgs, 0);
+                pgs = gs_state_saved(pgs);
+            }
+        }
+    }
 }
 
 const pcl_init_t    pcl_pattern_init = { pattern_do_registration, pattern_do_reset, 0 };
