@@ -9,7 +9,7 @@
    license.  Refer to licensing information at http://www.artifex.com/ or
    contact Artifex Software, Inc., 101 Lucas Valley Road #110,
    San Rafael, CA  94903, (415)492-9861, for further information. */
-/*$Id: pcsfont.c,v 1.40 2003/09/06 17:11:03 stefan Exp $ */
+/*$Id: pcsfont.c,v 1.43 2004/12/30 20:23:37 henrys Exp $ */
 
 /* pcsfont.c */
 /* PCL5 soft font creation commands */
@@ -253,8 +253,20 @@ pcl_font_header(pcl_args_t *pargs, pcl_state_t *pcs)
         memcpy(header, data, count);
         plfont->storage = pcds_temporary;
         plfont->data_are_permanent = false;
+        if (fst == plfst_Intellifont) {
+            /* lunacy not worth explaining */
+            uint gifct_offset;
+            if ( pfh->HeaderFormat == pcfh_intellifont_bound )
+                gifct_offset = 78;
+            else
+                gifct_offset = 78 + 8; /* + 8 for the character complement */
+            code = pl_swap_header(header, pl_get_uint16(header + gifct_offset));
+            if ( code != 0 )
+                return code;
+        }
         plfont->header = header;
         plfont->header_size = count;
+        plfont->is_xl_format = false;
         plfont->scaling_technology = fst;
         plfont->font_type = (pl_font_type_t)pfh->FontType;
         plfont->font_file = (char *)0;
@@ -579,6 +591,7 @@ pcl_character_data(pcl_args_t *pargs, pcl_state_t *pcs)
     if ( char_data == 0 ) { 
         char_data = gs_alloc_bytes(pcs->memory, font_data_size,
                                    "pcl_character_data");
+        memset(char_data, 0, font_data_size);
         if ( char_data == 0 )
             return_error(pcs->memory, e_Memory);
         /* if count > font_data_size extra data is ignored */
@@ -619,7 +632,7 @@ typedef enum resource_type_enum {
    on disk and add the macro to the macro dictionary */
 private void *
 pcl_find_resource(pcl_state_t *pcs,
-                  byte string_id[],
+                  const byte string_id[],
                   int string_id_size,
                   resource_type_t resource_type
                   )
