@@ -9,7 +9,7 @@
    license.  Refer to licensing information at http://www.artifex.com/ or
    contact Artifex Software, Inc., 101 Lucas Valley Road #110,
    San Rafael, CA  94903, (415)492-9861, for further information. */
-/*$Id: pctext.c,v 1.53 2004/01/29 23:58:13 henrys Exp $ */
+/*$Id: pctext.c,v 1.58 2004/12/30 20:24:53 henrys Exp $ */
 
 /* pctext.c -  PCL5 text printing commands */
 
@@ -23,6 +23,7 @@
 #include "pcdraw.h"
 #include "pcfont.h"
 #include "pcursor.h"
+#include "pcpage.h"
 #include "gdebug.h"
 #include "gscoord.h"
 #include "gsline.h"
@@ -45,23 +46,6 @@ private const pcl_text_parsing_method_t pcl_tpm_0 = pcl_tpm_0_data,
 #define	dots(n)	    ((float)(7200 / 300 * n))
 
 
-  private int
-get_gs_next_char(
-    gs_text_enum_t *    penum,
-    gs_char *           pchr,
-    gs_glyph *          pglyph
-)
-{
-    /* one character at a time */
-    //    assert(penum->text.size == 1);
-    if ( penum->index == 1 )
-        return 2;
-    *pglyph = gs_no_glyph;
-    *pchr = penum->text.data.chars[0];
-    penum->index++;
-    return 0;
-}
-
 /*
  * Install a font in the graphic state.
  */
@@ -89,10 +73,10 @@ map_symbol(
     /*
      * If there is no symbol map we assume the the character
      * implicitly indexes the font.
+     * Assumes internal fonts are either plfst_TrueType or plfst_MicroType
      */
     if (psm == 0) {
-	if ( (pfont->scaling_technology == plfst_TrueType) &&
-	     (pfont->storage == pcds_internal)               )
+	if ( pfont->storage == pcds_internal )
 	    return chr + 0xf000;
 	return chr;
     }
@@ -282,7 +266,7 @@ show_char_foreground(
     gs_font *pfont = plfont->pfont;
     gs_text_params_t text;
 
-    if (pcs->text_path == -1 && ((pbuff[0] & 0xff) != 0) && pcs->source_transparent) {
+    if (pcs->text_path == -1 && ((pbuff[0] & 0xff00) != 0) && pcs->source_transparent) {
     	/* -1 text path rotated text path; don't rotate 1 byte chars 
     	 * NB no support for opaque text
     	 * NB no support for centering about the center line of the glyph 
@@ -709,10 +693,17 @@ pcl_text(
         if (pfp->font->params.proportional_spacing) {
 	    scale.x = scale.y = pfp->params.height_4ths
 	                         * 0.25 * 7200.0 / ppi;
-	} else
+	} else {
 	    scale.x = scale.y = pl_fp_pitch_cp(&pfp->params)
 	                         * (100.0 / pl_fp_pitch_cp(&pfp->font->params))
 	                         * (7200.0 / (100.0 * ppi));
+	    if (1670 == pl_fp_pitch_per_inch_x100(&pfp->params) ) {
+		/* NB ArtLinePrinter.ttf : convert lineprinter glyphs to a taller aspect ratio 
+		 * 36x75 cell at 600dpi vs the fonts native 36x72 
+		 */
+		scale.y *= 1.0416667;
+	    }
+	}
 	/*
 	 * Scalable fonts use an upright coordinate system,
 	 * the opposite from the usual PCL system.
@@ -870,7 +861,6 @@ pcl_disable_underline(
     pcl_state_t *   pcs
 )
 {	
-    pcl_break_underline(pcs);
     pcs->underline_enabled = false;
     return 0;
 }
