@@ -1,4 +1,4 @@
-/* Portions Copyright (C) 2001 artofcode LLC.
+/* Portions Copyright (C) 2001, 2005 artofcode LLC.
    Portions Copyright (C) 1996, 2001 Artifex Software Inc.
    Portions Copyright (C) 1988, 2000 Aladdin Enterprises.
    This software is based in part on the work of the Independent JPEG Group.
@@ -9,7 +9,7 @@
    license.  Refer to licensing information at http://www.artifex.com/ or
    contact Artifex Software, Inc., 101 Lucas Valley Road #110,
    San Rafael, CA  94903, (415)492-9861, for further information. */
-/*$Id: pcuptrn.c,v 1.23 2003/09/06 17:11:03 stefan Exp $ */
+/*$Id: pcuptrn.c,v 1.27 2005/02/23 17:56:51 stefan Exp $ */
 
 /* pcuptrn.c - code for PCL and GL/2 user defined patterns */
 
@@ -543,6 +543,8 @@ upattern_do_copy(pcl_state_t *psaved, const pcl_state_t *pcs,
        pcl_pattern_clear_bi_patterns() below */
     for(i = 0; i < countof(pcs->bi_pattern_array); i++)
 	psaved->bi_pattern_array[i] = pcs->bi_pattern_array[i];
+    psaved->gl_patterns = pcs->gl_patterns;
+    psaved->pcl_patterns = pcs->pcl_patterns;
     return 0;
 }
 
@@ -585,8 +587,8 @@ upattern_do_reset(
         pcs->last_gl2_RF_indx = -1;
         pcs->plast_gl2_uptrn = 0;
 
-    } else if ((type & (pcl_reset_cold | pcl_reset_printer)) != 0) {
-        delete_all_pcl_ptrns(true, true, pcs);
+    } else if ((type & (pcl_reset_cold | pcl_reset_printer | pcl_reset_permanent)) != 0) {
+        delete_all_pcl_ptrns(true, !(type & pcl_reset_permanent) , pcs);
         pcl_pattern_clear_bi_patterns(pcs);
         /* GL's IN command takes care of the GL patterns */
     }
