@@ -9,7 +9,7 @@
    license.  Refer to licensing information at http://www.artifex.com/ or
    contact Artifex Software, Inc., 101 Lucas Valley Road #110,
    San Rafael, CA  94903, (415)492-9861, for further information. */
-/*$Id: pgconfig.c,v 1.30 2003/09/06 17:11:03 stefan Exp $ */
+/*$Id: pgconfig.c,v 1.31 2004/11/15 16:16:33 stefan Exp $ */
 
 /* pgconfig.c */
 /* HP-GL/2 configuration and status commands */
@@ -613,6 +613,47 @@ private int
 hpgl_BP(hpgl_args_t *pargs, hpgl_state_t *pgls)
 {	
     hpgl_args_t args;
+    int32 command = 0;
+    int32 value = 0;
+    bool more = true;
+
+
+    while (more) {
+        more = hpgl_arg_int(pgls->memory, pargs, &command);
+	if (!more) 
+	    break;
+	if (command == 1) {
+	    /* parse string */ 
+	    const byte *p = pargs->source.ptr;
+	    const byte *rlimit = pargs->source.limit;	    
+	    while ( p < rlimit ) {
+		switch ( *++p ) {
+		case ' ':
+		    /* Ignore spaces between command and opening ". */
+		    continue;	
+		case '"':
+		    if ( !pargs->phase ) {
+			/* begin string */
+			pargs->phase = 1;
+			continue;
+		    }
+		    else /* end string */
+			break;
+		default:
+		    if ( !pargs->phase ) 
+			break; 			/* ill formed command exit */
+		    else
+			continue;               /* character inside of string */
+		}
+		break;  /* error or trailing " exits */
+	    }
+	    pargs->source.ptr = p;
+	} 
+	else {
+	    more = hpgl_arg_int(pgls->memory, pargs, &value);
+	    /* BP command value pair is currently ignored */
+	}
+    }
 
     hpgl_args_setup(&args);
     hpgl_IN(&args, pgls);
