@@ -9,7 +9,7 @@
    license.  Refer to licensing information at http://www.artifex.com/ or
    contact Artifex Software, Inc., 101 Lucas Valley Road #110,
    San Rafael, CA  94903, (415)492-9861, for further information. */
-/*$Id: pgdraw.c,v 1.73 2003/09/06 17:11:03 stefan Exp $ */
+/*$Id: pgdraw.c,v 1.75 2005/01/06 19:48:40 henrys Exp $ */
 
 /* pgdraw.c - HP-GL/2 line drawing/path building routines. */
 
@@ -354,13 +354,13 @@ hpgl_get_selected_pen(hpgl_state_t *pgls)
     /* get the current pen */
     int pen = pgls->g.pen.selected;
     /* 0 is the first pen */
-    int max_pen = pcl_palette_get_num_entries(pgls->ppalet) - 1;
+    int num_entries = pcl_palette_get_num_entries(pgls->ppalet);
     /* this is bad */
-    if ( pen < 0 )
-	pen = -pen;
-    /* try to recover if necessary */
-    while ( pen > max_pen )
-	pen = pen - max_pen;
+    if ((pen < 0) || (pen >= num_entries)) {
+        pen %= num_entries;
+        if (pen < 0)
+            pen += num_entries;
+    }
     return pen;
 }
 
@@ -814,15 +814,15 @@ hpgl_polyfill(
  private int
 hpgl_fill_polyfill_background(hpgl_state_t *pgls)
 {
+    /* conditionally mark page as dirty */
+    pcl_mark_page_for_path(pgls);
     /* if we are drawing on a transparent background */
     if ( pgls->g.source_transparent )
 	return 0;
     /* preserve the current foreground color */
     hpgl_call(hpgl_gsave(pgls));
-    /* fill a white region.  NB have not experimented with different
-       rasterops and transparency. */
+    /* fill a white region. */
     hpgl_call(gs_setgray(pgls->pgs, 1.0));
-    pcl_mark_page_for_path(pgls);
     hpgl_call(gs_fill(pgls->pgs));
     /* restore the foreground color */
     hpgl_call(hpgl_grestore(pgls));
