@@ -9,7 +9,7 @@
    license.  Refer to licensing information at http://www.artifex.com/ or
    contact Artifex Software, Inc., 101 Lucas Valley Road #110,
    San Rafael, CA  94903, (415)492-9861, for further information. */
-/*$Id: plfont.c,v 1.32 2004/02/02 20:49:42 stefan Exp $ */
+/*$Id: plfont.c,v 1.36 2004/12/30 21:40:17 henrys Exp $ */
 
 /* plfont.c */
 /* PCL font handling library -- operations on entire fonts */
@@ -34,10 +34,6 @@
 /* Structure descriptors */
 private_st_pl_font();
 
-/* Imported procedures */
-int gs_type42_get_metrics(gs_font_type42 *pfont, uint glyph_index,
-  float psbw[4]);
-
 /* Define accessors for unaligned, big-endian quantities. */
 #define u16(bptr) pl_get_uint16(bptr)
 #define s16(bptr) pl_get_int16(bptr)
@@ -55,7 +51,7 @@ pl_free_font(gs_memory_t *mem, void *plf, client_name_t cname)
 	  { if ( plfont->glyphs.table )
 	     { uint i;
 	       for ( i = plfont->glyphs.size; i > 0; )
-	         { void *data = plfont->glyphs.table[--i].data;
+                 { void *data = (void *)plfont->glyphs.table[--i].data;
 	           if ( data )
 		     gs_free_object(mem, data, cname);
 	         }  
@@ -405,7 +401,7 @@ pl_glyph_name(gs_font *pfont, gs_glyph glyph, gs_const_string *pstr)
         } else {
             char *mydata;
             /* and here's the tricky part */
-            byte *pascal_stringp = 
+            const byte *pascal_stringp = 
                 postp + 34 + (numGlyphs * 2);
             /* 0 - 257 lives in the mac table above */
             glyph_name_index -= 258;
@@ -450,12 +446,6 @@ pl_decode_glyph(gs_font *font,  gs_glyph glyph)
     return last_char;
 }
 
-/* Get a glyph from a known encoding.  We don't support this either. */
-private gs_glyph
-pl_known_encode(gs_char chr, int encoding_index)
-{	return gs_no_glyph;
-}
-
 /* ---------------- Public procedures ---------------- */
 
 /* character width */
@@ -470,7 +460,6 @@ int pl_font_char_metrics(const pl_font_t *plfont, const void *pgs, uint char_cod
     return (*(plfont)->char_metrics)(plfont, pgs, char_code, metrics);
 }
 
-
 /* Allocate a font. */
 pl_font_t *
 pl_alloc_font(gs_memory_t *mem, client_name_t cname)
@@ -491,6 +480,7 @@ pl_alloc_font(gs_memory_t *mem, client_name_t cname)
 	    plfont->params.proportional_spacing = true;
 	    memset(plfont->character_complement, 0xff, 8);
 	    plfont->offsets.GC = plfont->offsets.GT = plfont->offsets.VT = -1;
+	    plfont->pts_per_inch = 72.0;   /* normal value */
 	  }
 	return plfont;
 }
@@ -516,6 +506,7 @@ pl_clone_font(const pl_font_t *src, gs_memory_t *mem, client_name_t cname)
 	plfont->storage = src->storage;
 	plfont->header_size = src->header_size;
 	plfont->scaling_technology = src->scaling_technology;
+        plfont->is_xl_format = src->is_xl_format;
 	plfont->font_type = src->font_type;
 	plfont->char_width = src->char_width;
 	plfont->char_metrics = src->char_metrics;
@@ -585,6 +576,8 @@ pl_clone_font(const pl_font_t *src, gs_memory_t *mem, client_name_t cname)
 	      }
 	      break;
 	    }
+          default:
+              return 0;
 	  }
 	if ( src->char_glyphs.table != 0 )
 	  {
@@ -619,7 +612,7 @@ pl_clone_font(const pl_font_t *src, gs_memory_t *mem, client_name_t cname)
 	    plfont->glyphs.skip = src->glyphs.skip;
 	    for ( i = 0; i < src->glyphs.size; i++ )
 	      {
-		byte *data = src->glyphs.table[i].data;
+		const byte *data = src->glyphs.table[i].data;
 		byte *char_data;
 		plfont->glyphs.table[i].glyph =
 		  src->glyphs.table[i].glyph;
@@ -971,26 +964,9 @@ pl_load_tt_font(FILE *in, gs_font_dir *pdir, gs_memory_t *mem,
 	    plfont->font_type = plft_Unicode;
 	    plfont->large_sizes = true;
 	    plfont->offsets.GT = 0;
+            plfont->is_xl_format = false;
 	    pl_fill_in_tt_font(pfont, tt_font_datap, unique_id);
 	    code = gs_definefont(pdir, (gs_font *)pfont);
-	    if ( code >= 0 ) { 
-		/*
-		 * Set the nominal design width to the
-		 * width of a small 'x' character.  If
-		 * there isn't one, set the design
-		 * width arbitrarily at 0.6 em.  */
-		gs_char space = ' ';
-		float sbw[4];
-		uint glyph_index =
-		    (*pfont->procs.encode_char)
-		    ((gs_font *)pfont, space, gs_no_glyph);
-
-		if (glyph_index == gs_no_glyph || glyph_index == 0xffff)
-		    glyph_index = 0;
-		if ( gs_type42_get_metrics(pfont, glyph_index, sbw) < 0 )
-		    sbw[2] = 0.6;
-		pl_fp_set_pitch_cp(&plfont->params, sbw[2] * 100);
-	    }
 	}
     }
     if ( code < 0 ) { 
