@@ -9,7 +9,7 @@
    license.  Refer to licensing information at http://www.artifex.com/ or
    contact Artifex Software, Inc., 101 Lucas Valley Road #110,
    San Rafael, CA  94903, (415)492-9861, for further information. */
-/*$Id: plufont.c,v 1.19 2004/02/27 17:57:38 stefan Exp $ */
+/*$Id: plufont.c,v 1.25 2004/12/30 21:05:17 henrys Exp $ */
 
 /* plfont.c */
 /* PCL font handling library -- operations on entire fonts */
@@ -32,20 +32,26 @@
 
 /* agfa stuff */
 #include "cgconfig.h"     /* this must be first  */
-#include "port.h"         /* this must be second */
+#include "ufstport.h"         /* this must be second */
+#include "shareinc.h"
 
 /* Structure descriptors */
 private_st_pl_font();
 
-/* Imported procedures */
-int gs_type42_get_metrics(gs_font_type42 *pfont, uint glyph_index, float psbw[4]);
-
 /* Define accessors for unaligned, big-endian quantities. */
 #define u16(bptr) pl_get_uint16(bptr)
 #define s16(bptr) pl_get_int16(bptr)
 /**** ASSUME uint >= 32 BITS ****/
 #define u32(bptr) (uint)pl_get_uint32(bptr)
 
+
+extern void pl_init_fc(
+    const pl_font_t *   plfont,
+    gs_state *          pgs,
+    int                 need_outline,
+    FONTCONTEXT *       pfc,
+    bool                width_request);
+
 /* ---------------- Utilities ---------------- */
 
 /* Free a font.  This is the freeing procedure in the font dictionary. */
@@ -57,7 +63,7 @@ pl_free_font(gs_memory_t *mem, void *plf, client_name_t cname)
 	  { if ( plfont->glyphs.table )
 	     { uint i;
 	       for ( i = plfont->glyphs.size; i > 0; )
-	         { void *data = plfont->glyphs.table[--i].data;
+                 { void *data = (void *)plfont->glyphs.table[--i].data;
 	           if ( data )
 		     gs_free_object(mem, data, cname);
 	         }  
@@ -65,8 +71,6 @@ pl_free_font(gs_memory_t *mem, void *plf, client_name_t cname)
 	     gs_free_object(mem, (void *)plfont->header, cname);
 	     plfont->header = 0; /* see hack note above */
 	  }
-	if (plfont->scaling_technology != plfst_bitmap)
-	    pl_purge_ufst_font(plfont);
 	/* Free the font data itself. */
 	gs_free_object(mem, (void *)plfont->char_glyphs.table, cname);
 	gs_free_object(mem, (void *)plfont->glyphs.table, cname);
@@ -74,6 +78,9 @@ pl_free_font(gs_memory_t *mem, void *plf, client_name_t cname)
 	  { gs_purge_font(plfont->pfont);
 	    gs_free_object(mem, plfont->pfont, cname);
 	  }
+	if ( plfont->font_file ) {
+	    gs_free_object(mem, plfont->font_file, cname);
+	}
 	gs_free_object(mem, plf, cname);
 }
 
@@ -85,7 +92,7 @@ pl_glyph_name(gs_glyph glyph, uint *plen)
 {	return 0;
 }
 
-gs_char last_char = '!';
+extern gs_char last_char;
 /* Get the unicode valude for a glyph */
 private gs_char
 pl_decode_glyph(gs_font *font,  gs_glyph glyph)
@@ -97,14 +104,6 @@ pl_decode_glyph(gs_font *font,  gs_glyph glyph)
     return last_char;
 }
 
-/* Get a glyph from a known encoding.  We don't support this either. */
-private gs_glyph
-pl_known_encode(gs_char chr, int encoding_index)
-{	return gs_no_glyph;
-}
-
-/* ---------------- Public procedures ---------------- */
-
 /* ---------------- Public procedures ---------------- */
 
 /* character width */
@@ -134,7 +133,6 @@ pl_alloc_font(gs_memory_t *mem, client_name_t cname)
 	    /* Initialize other defaults. */
 	    plfont->landscape = false;
 	    plfont->bold_fraction = 0;
-	    plfont->is_xl_format1 = false;
 	    plfont->font_file = 0;
 	    plfont->resolution.x = plfont->resolution.y = 0;
 	    plfont->params.proportional_spacing = true;
@@ -159,164 +157,108 @@ pl_font_t *
 pl_clone_font(const pl_font_t *src, gs_memory_t *mem, client_name_t cname)
 {
     pl_font_t *plfont;
-    /* it is not clear how to clone resident ufst fco fonts unless
-       they are downloaded */
-    dprintf(mem, "clone fonts\n" );
-
-    if (src->header == 0)
-        return 0;
-    plfont = gs_alloc_struct(mem, pl_font_t, &st_pl_font, cname);
+    ulong header_size;
+    plfont = (pl_font_t *)gs_alloc_bytes(mem, gs_object_size(mem, src), cname);
     if ( plfont == 0 )
         return 0;
-    /* copy technology common parts */
-    plfont->storage = src->storage;
-    plfont->header_size = src->header_size;
-    plfont->scaling_technology = src->scaling_technology;
-    plfont->font_type = src->font_type;
-    plfont->char_width = src->char_width;
-    plfont->large_sizes = src->large_sizes;
-    plfont->resolution = src->resolution;
-    plfont->params = src->params;
-    plfont->pts_per_inch = src->pts_per_inch;
-    plfont->font_file_loaded = src->font_file_loaded;
-    plfont->landscape = src->landscape;
-    plfont->bold_fraction = src->bold_fraction;
-
-    {
-        int i;
-        for (i = 0; i < sizeof(src->character_complement); i++ )
-	    plfont->character_complement[i] = src->character_complement[i];
+    *plfont = *src;
+    /* NB gs_object_size returns uint */
+    header_size = (ulong)gs_object_size(mem, src->header);
+    if (header_size != 0) {
+        plfont->header = gs_alloc_bytes(mem, header_size, cname);
+        if ( plfont->header == 0 )
+            return 0;
+        memcpy(plfont->header, src->header, header_size);
     }
-    plfont->offsets = src->offsets;
-    if (src->header_size > 0)
-        {
-            plfont->header = gs_alloc_bytes(mem, src->header_size, cname);
-            if ( plfont->header == 0 )
-                return 0;
-            memcpy(plfont->header, src->header, src->header_size);
-        }
-    else
-        plfont->header = 0;
-
     /* technology specific setup */
-    switch ( plfont->scaling_technology )
+    switch ( plfont->scaling_technology ) {
+    case plfst_bitmap:
         {
-        case plfst_bitmap:
-	    {
-                gs_font_base *pfont =
-                    gs_alloc_struct(mem, gs_font_base, &st_gs_font_base, cname);
+            gs_font_base *pfont =
+                gs_alloc_struct(mem, gs_font_base, &st_gs_font_base, cname);
+            if ( pfont == 0 )
+                return 0;
+            pl_fill_in_font((gs_font *)pfont, plfont, src->pfont->dir, mem, "illegal font");
+            pl_fill_in_bitmap_font(pfont, gs_next_ids(mem, 1));
+            break;
+        }
+    case plfst_Intellifont:
+        {
+            gs_font_base *pfont =
+                gs_alloc_struct(mem, gs_font_base, &st_gs_font_base, cname);
+            if ( pfont == 0 )
+                return 0;
+            pl_fill_in_font((gs_font *)pfont, plfont, src->pfont->dir, mem, "illegal font");
+            pl_fill_in_intelli_font(pfont, gs_next_ids(mem, 1));
+            break;
+        }
+    case plfst_TrueType:
+        {
+            {
+                gs_font_type42 *pfont =
+                    gs_alloc_struct(mem, gs_font_type42, &st_gs_font_type42, cname);
                 if ( pfont == 0 )
                     return 0;
-                pl_fill_in_font((gs_font *)pfont, plfont, src->pfont->dir, mem, "illegal font");
-                pl_fill_in_bitmap_font(pfont, gs_next_ids(mem, 1));
-                break;
-	    }
-        case plfst_Intellifont:
-	    {
-                gs_font_base *pfont =
-                    gs_alloc_struct(mem, gs_font_base, &st_gs_font_base, cname);
-                if ( pfont == 0 )
+                pl_fill_in_font((gs_font *)pfont,
+                                plfont, src->pfont->dir,
+                                mem, "illegal font");
+                pl_fill_in_tt_font(pfont, NULL, gs_next_ids(mem, 1));
+            }
+            break;
+        }
+    case plfst_MicroType:
+        {
+            gs_font_base *pfont =
+                gs_alloc_struct(mem, gs_font_base, &st_gs_font_base, cname);
+            if ( pfont == 0 )
+                return 0;
+            pl_fill_in_font((gs_font *)pfont, plfont, src->pfont->dir, mem, "illegal font");
+            pl_fill_in_mt_font(pfont, 0, 0);
+            pfont->UID = ((gs_font_base *)(src->pfont))->UID; /*** HACK ***/
+            break;
+        }
+    }
+    if ( src->char_glyphs.table != 0 ) {
+        pl_tt_char_glyph_t *char_glyphs =
+            (pl_tt_char_glyph_t *) gs_alloc_byte_array(mem,
+                                                       src->char_glyphs.size,
+                                                       sizeof(pl_tt_char_glyph_t), cname);
+        int i;
+        if ( char_glyphs == 0 )
+            return 0;
+        for ( i = 0; i < src->char_glyphs.size; i++ )
+            char_glyphs[i] = src->char_glyphs.table[i];
+        /* once again a copy struct shortcut and then are restore
+           of the char_glyphs.table pointer */
+        plfont->char_glyphs = src->char_glyphs;
+        plfont->char_glyphs.table = char_glyphs;
+    }
+
+    if ( src->glyphs.table != 0 ) {
+        int i;
+        plfont->glyphs.table = 
+            gs_alloc_struct_array(mem, src->glyphs.size, pl_font_glyph_t,
+                                  &st_pl_font_glyph_element_f, cname);
+        plfont->glyphs.used = src->glyphs.used;
+        plfont->glyphs.limit = src->glyphs.limit;
+        plfont->glyphs.size = src->glyphs.size;
+        plfont->glyphs.skip = src->glyphs.skip;
+        for ( i = 0; i < src->glyphs.size; i++ ) {
+            byte *data = src->glyphs.table[i].data;
+            byte *char_data;
+            plfont->glyphs.table[i].glyph =
+                src->glyphs.table[i].glyph;
+            plfont->glyphs.table[i].data = 0;
+            if ( data ) {
+                uint size = gs_object_size(mem, data);
+                char_data = gs_alloc_bytes(mem, size, cname);
+                if ( char_data == 0 )
                     return 0;
-                pl_fill_in_font((gs_font *)pfont, plfont, src->pfont->dir, mem, "illegal font");
-                pl_fill_in_intelli_font(pfont, gs_next_ids(mem, 1));
-                break;
-	    }
-        case plfst_TrueType:
-	    {
-                {
-                    gs_font_type42 *pfont =
-                        gs_alloc_struct(mem, gs_font_type42, &st_gs_font_type42, cname);
-                    /* detect if a truetype font is downloaded or
-                       internal.  There must be a better way... */
-                    gs_font_type42 *pfont_src = (gs_font_type42 *)src->pfont;
-                    bool downloaded = (pfont_src->data.get_outline == pl_tt_get_outline);
-                    if ( pfont == 0 )
-                        return 0;
-                    pl_fill_in_font((gs_font *)pfont, plfont, src->pfont->dir, mem, "illegal font");
-                    pl_fill_in_tt_font(pfont, downloaded ? NULL : src->header, gs_next_ids(mem, 1));
-                }
-                break;
-	    }
-        case plfst_MicroType:
-	    {
-                gs_font_base *pfont =
-                    gs_alloc_struct(mem, gs_font_base, &st_gs_font_base, cname);
-                if ( pfont == 0 )
-                    return 0;
-                pl_fill_in_font((gs_font *)pfont, plfont, src->pfont->dir, mem, "illegal font");
-                pl_fill_in_mt_font(pfont, 0, 0);
-                pfont->UID = ((gs_font_base *)(src->pfont))->UID; /*** HACK ***/
-                break;
+                memcpy(char_data, data, size);
+                plfont->glyphs.table[i].data = char_data;
             }
         }
-    if ( src->char_glyphs.table != 0 )
-        {
-	    /* HAS may gs_alloc_struct_array() here but this is
-	       consistant with pl_tt_alloc_char_glyphs() */
-	    pl_tt_char_glyph_t *char_glyphs =
-                (pl_tt_char_glyph_t *) gs_alloc_byte_array(mem,
-                                                           src->char_glyphs.size,
-                                                           sizeof(pl_tt_char_glyph_t), cname);
-	    int i;
-	    if ( char_glyphs == 0 )
-                return 0;
-	    for ( i = 0; i < src->char_glyphs.size; i++ )
-                char_glyphs[i] = src->char_glyphs.table[i];
-	    /* once again a copy struct shortcut and then are restore
-               of the char_glyphs.table pointer */
-	    plfont->char_glyphs = src->char_glyphs;
-	    plfont->char_glyphs.table = char_glyphs;
-        }
-    else /* no character glyph table data */
-        plfont->char_glyphs = src->char_glyphs;
-
-    if ( src->glyphs.table != 0 )
-        {
-	    int i;
-	    plfont->glyphs.table = 
-                gs_alloc_struct_array(mem, src->glyphs.size, pl_font_glyph_t,
-                                      &st_pl_font_glyph_element_f, cname);
-	    plfont->glyphs.used = src->glyphs.used;
-	    plfont->glyphs.limit = src->glyphs.limit;
-	    plfont->glyphs.size = src->glyphs.size;
-	    plfont->glyphs.skip = src->glyphs.skip;
-	    for ( i = 0; i < src->glyphs.size; i++ )
-                {
-                    byte *data = src->glyphs.table[i].data;
-                    byte *char_data;
-                    plfont->glyphs.table[i].glyph =
-                        src->glyphs.table[i].glyph;
-                    plfont->glyphs.table[i].data = 0;
-                    if ( data )
-                        { /* ARGH --- */
-                            uint size;
-                            if ( plfont->scaling_technology == plfst_bitmap )
-                                {
-                                    size = 16 +
-                                        ((pl_get_uint16(data + 10) + 7) >> 3) *
-                                        pl_get_uint16(data + 12);
-                                }
-                            else if ( plfont->scaling_technology == plfst_Intellifont ) {
-                                /* non compound characters */
-                                if ( data[3] == 3 )
-                                    size = 6 + pl_get_uint16(data + 4);
-                                else /* assume data[3] == 4 (compound) */
-                                    size = 8 + data[6] * 6 + 2;
-                            }
-                            else /* truetype */
-                                size = 2 + 2 + data[2] +
-                                    pl_get_uint16(data + 2 + data[2]);
-                            char_data = gs_alloc_bytes(mem, size, cname);
-                            if ( char_data == 0 )
-                                return 0;
-                            memcpy(char_data, data, size);
-                            plfont->glyphs.table[i].data = char_data;
-                        }
-
-                }
-        }
-    else /* no glyph table */
-        plfont->glyphs = src->glyphs;
+    }
     return plfont;
 }
 	
@@ -331,6 +273,7 @@ pl_fill_in_font(gs_font *pfont, pl_font_t *plfont, gs_font_dir *pdir,
 	pfont->next = pfont->prev = 0;
 	pfont->memory = mem;
 	pfont->dir = pdir;
+	pfont->is_resource = false;  
 	gs_notify_init(&pfont->notify_list, gs_memory_stable(mem));
 	pfont->base = pfont;
 	pfont->client_data = plfont;
@@ -346,6 +289,8 @@ pl_fill_in_font(gs_font *pfont, pl_font_t *plfont, gs_font_dir *pdir,
 	pfont->procs.define_font = gs_no_define_font;
 	pfont->procs.make_font = gs_no_make_font;
 	pfont->procs.font_info = gs_default_font_info;
+        pfont->procs.glyph_info = gs_default_glyph_info;
+        pfont->procs.glyph_outline = gs_no_glyph_outline;
 	pfont->id = gs_next_ids(mem, 1);
 	strncpy(pfont->font_name.chars, font_name, sizeof(pfont->font_name.chars));
 	pfont->font_name.size = strlen(font_name);
@@ -434,7 +379,8 @@ pl_fill_in_intelli_font(gs_font_base *pfont, long unique_id)
  * large_sizes = false indicates 2-byte segment sizes, true indicates 4-byte.
  */
 int
-pl_font_scan_segments(const gs_memory_t *mem, pl_font_t *plfont, int fst_offset, int start_offset,
+pl_font_scan_segments(const gs_memory_t *mem,
+		      pl_font_t *plfont, int fst_offset, int start_offset,
   long end_offset, bool large_sizes, const pl_font_offset_errors_t *pfoe)
 {	const byte *header = plfont->header;
 	pl_font_scaling_technology_t fst = header[fst_offset];
@@ -515,7 +461,7 @@ pl_font_scan_segments(const gs_memory_t *mem, pl_font_t *plfont, int fst_offset,
 		    /*
 		     * We don't do much checking here, but we do check that
 		     * the segment starts with a table directory that
-		     * includes at least 5 elements (gdir, head, hhea, hmtx,
+		     * includes at least 3 elements (gdir, head,
 		     * maxp -- but we don't check the actual names).
 		     */
 		    if ( seg_size < 12 + 5 * 16 ||
@@ -595,84 +541,6 @@ pl_alloc_tt_fontfile_buffer(FILE *in, gs_memory_t *mem, byte **pptt_font_data, u
     return 0;
 }
 
-/* Load a built-in (TrueType) font from external storage. */
-int
-pl_load_tt_font(FILE *in, gs_font_dir *pdir, gs_memory_t *mem,
-  long unique_id, pl_font_t **pplfont, char *font_name)
-{	ulong len = (fseek(in, 0L, SEEK_END), ftell(in));
-	ulong size = 6 + len;	/* leave room for segment header */
-	byte *data;
-
-	if ( size != (uint)size )
-	  { /*
-	     * The font is too big to load in a single piece -- punt.
-	     * The error message is bogus, but there isn't any more
-	     * appropriate one.
-	     */
-	    fclose(in);
-	    return_error(mem, gs_error_VMerror);
-	  }
-	rewind(in);
-	data = gs_alloc_bytes(mem, size, "pl_tt_load_font data");
-	if ( data == 0 )
-	  { fclose(in);
-	    return_error(mem, gs_error_VMerror);
-	  }
-	fread(data + 6, 1, len, in);
-	fclose(in);
-	/* Make a Type 42 font out of the TrueType data. */
-	{ gs_font_type42 *pfont =
-	    gs_alloc_struct(mem, gs_font_type42, &st_gs_font_type42,
-			    "pl_tt_load_font(gs_font_type42)");
-	  pl_font_t *plfont = pl_alloc_font(mem, "pl_tt_load_font(pl_font_t)");
-	  int code;
-
-	  if ( pfont == 0 || plfont == 0 )
-	    code = gs_note_error(mem, gs_error_VMerror);
-	  else
-	    { /* Initialize general font boilerplate. */
-	      code = pl_fill_in_font((gs_font *)pfont, plfont, pdir, mem, "illegal font");
-	      if ( code >= 0 )
-		{ /* Initialize TrueType font boilerplate. */
-		  plfont->header = data;
-		  plfont->header_size = size;
-		  plfont->scaling_technology = plfst_TrueType;
-		  plfont->font_type = plft_Unicode;
-		  plfont->large_sizes = true;
-		  plfont->offsets.GT = 0;
-		  pl_fill_in_tt_font(pfont, data, unique_id);
-		  code = gs_definefont(pdir, (gs_font *)pfont);
-		  if ( code >= 0 )
-		    { /*
-		       * Set the nominal design width to the width of a
-		       * small 'x' character.  If there isn't one, set the
-		       * design width arbitrarily at 0.6 em.
-		       */
-		      gs_char space = ' ';
-		      float sbw[4];
-		      uint glyph_index =
-			(*pfont->procs.encode_char)
-			  ((gs_font *)pfont, space, gs_no_glyph);
-
-		      if (glyph_index == gs_no_glyph || glyph_index == 0xffff)
-			glyph_index = 0;
-		      if ( gs_type42_get_metrics(pfont, glyph_index, sbw) < 0 )
-			sbw[2] = 0.6;
-		      pl_fp_set_pitch_cp(&plfont->params, sbw[2] * 100);
-		    }
-		}
-	    }
-	  if ( code < 0 )
-	    { gs_free_object(mem, plfont, "pl_tt_load_font(pl_font_t)");
-	      gs_free_object(mem, pfont, "pl_tt_load_font(gs_font_type42)");
-	      gs_free_object(mem, data, "pl_tt_load_font data");
-	      return code;
-	    }
-	  *pplfont = plfont;
-	}
-	return 0;
-}
-
 /* Fill in AGFA MicroType font boilerplate. */
 void
 pl_fill_in_mt_font(gs_font_base *pfont, SW16 data, long unique_id)
@@ -713,6 +581,7 @@ pl_load_mt_font(SW16 handle, gs_font_dir *pdir, gs_memory_t *mem,
                   plfont->scaling_technology = plfst_MicroType;
                   plfont->font_type = plft_Unicode;
                   plfont->large_sizes = true;
+                  plfont->is_xl_format = false;
                   pl_fill_in_mt_font(pfont, handle, unique_id);
                   code = gs_definefont(pdir, (gs_font *)pfont);
               }
