@@ -9,7 +9,7 @@
    license.  Refer to licensing information at http://www.artifex.com/ or
    contact Artifex Software, Inc., 101 Lucas Valley Road #110,
    San Rafael, CA  94903, (415)492-9861, for further information. */
-/*$Id: plulfont.c,v 1.16 2004/02/27 17:57:38 stefan Exp $ */
+/*$Id: plulfont.c,v 1.18 2004/09/01 06:23:34 henrys Exp $ */
 
 /* plulfont.c */
 /* PCL5 font preloading */
@@ -26,7 +26,7 @@
 #include "plvalue.h"
 /* agfa includes */
 #include "cgconfig.h"
-#include "port.h"
+#include "ufstport.h"
 #include "shareinc.h"
 /* set to 1 to display UFST debugging statements */
 SW16 trace_sw = 0;
@@ -45,11 +45,11 @@ private SW16  fcHndlAry[16];
 /* defaults for locations of font collection objects (fco's) and
    plugins the root data directory.  These are internally separated with
    ':' but environment variable use the gp separator */
-const char *UFSTFONTDIR="/usr/local/fontdata/";
+const char *UFSTFONTDIR="/usr/local/fontdata2/";
 
 /* default list of fcos and plugins - relative to UFSTFONTDIR */
-const char *UFSTFCOS="mtfonts/pclps2/mt1/pclp2__g.fco:mtfonts/pcl45/mt1/wd_____g.fco";
-const char *UFSTPLUGINS="mtfonts/pcl45/mt1/plug___g.fco";
+const char *UFSTFCOS="mtfonts/pclps2/mt1/pclp2__i.fco:mtfonts/pcl45/mt1/wd_____g.fco";
+const char *UFSTPLUGINS="mtfonts/pcl45/mt1/plug___i.fco";
 
 /* return a null terminated array of strings on the heap from
    str0:str1:str:.  Use gs separator */
@@ -296,7 +296,7 @@ pl_load_built_in_fonts(const char *pathname, gs_memory_t *mem, pl_dict_t *pfontd
                                   err_cd,
                                   pname );
                     else {
-                        dprintf1( mem, "Loading %s\n", pname );
+                        dprintf2( mem, "Loading %s from fco %s\n", pname, plugins[k] );
                         uint    pitch_cp = (pfDesc->spaceBand * 100.0)
                             / pfDesc->scaleFactor + 0.5;
 
@@ -308,7 +308,7 @@ pl_load_built_in_fonts(const char *pathname, gs_memory_t *mem, pl_dict_t *pfontd
                             pitch_cp = (pfDesc->spaceBand * 100 * 72.0)
                                          / (pfDesc->scaleFactor * 72.307) + 0.5;
                         }
-
+                        dprintf3( mem, "scale factor=%d, pitch (cp)=%d per_inch_x100=%d\n", pfDesc->scaleFactor, pitch_cp, (uint)(720000.0/pitch_cp));
                         if (resident_table[j].params.symbol_set != 0)
                             plfont->font_type = plft_8bit;
 
@@ -420,7 +420,7 @@ pl_load_built_in_fonts(const char *pathname, gs_memory_t *mem, pl_dict_t *pfontd
                     else {
                         uint    pitch_cp = (pfDesc->spaceBand * 100.0)
                             / pfDesc->scaleFactor + 0.5;
-
+                        dprintf2( mem, "Loading %s from fco %s\n", pname, fcos[k] );
                         /* Record the differing points per inch value
                            for Intellifont derived fonts. */
 
@@ -429,7 +429,7 @@ pl_load_built_in_fonts(const char *pathname, gs_memory_t *mem, pl_dict_t *pfontd
                             pitch_cp = (pfDesc->spaceBand * 100 * 72.0)
                                          / (pfDesc->scaleFactor * 72.307) + 0.5;
                         }
-
+                        dprintf3( mem, "scale factor=%d, pitch (cp)=%d per_inch_x100=%d\n", pfDesc->scaleFactor, pitch_cp, (uint)(720000.0/pitch_cp));
                         if (resident_table[j].params.symbol_set != 0)
                             plfont->font_type = plft_8bit;
 
