@@ -9,7 +9,7 @@
    license.  Refer to licensing information at http://www.artifex.com/ or
    contact Artifex Software, Inc., 101 Lucas Valley Road #110,
    San Rafael, CA  94903, (415)492-9861, for further information. */
-/* $Id: psitop.c,v 1.17 2003/12/16 16:19:00 stefan Exp $ */
+/* $Id: psitop.c,v 1.18 2005/01/02 16:24:11 stefan Exp $ */
 
 /* psitop.c */
 /* Top-level API implementation of PS Language Interface */
@@ -174,7 +174,8 @@ ps_impl_allocate_interp_instance(
 private int   /* ret 0 ok, else -ve error code */
 ps_impl_set_client_instance(
   pl_interp_instance_t   *instance,     /* interp instance to use */
-  pl_interp_instance_t   *client        /* client to set */
+  pl_interp_instance_t   *client,       /* client to set */
+  pl_interp_instance_clients_t which_client
 )
 {
 	return 0;
@@ -460,8 +461,6 @@ ps_impl_deallocate_interp(
 	return 0;
 }
 
-extern pl_interp_instance_t *get_interpreter_from_memory( const gs_memory_t *mem );
-
 /* 
  * End-of-page called back by PS
  */
