@@ -9,7 +9,7 @@
    license.  Refer to licensing information at http://www.artifex.com/ or
    contact Artifex Software, Inc., 101 Lucas Valley Road #110,
    San Rafael, CA  94903, (415)492-9861, for further information. */
-/*$Id: pxfont.c,v 1.27 2004/01/30 00:23:05 henrys Exp $ */
+/*$Id: pxfont.c,v 1.33 2004/12/30 22:03:08 henrys Exp $ */
 
 /* pxfont.c */
 /* PCL XL font operators */
@@ -38,16 +38,6 @@
 #include "gxpath.h"
 #include "gzstate.h"
 
-/*
- * There appears to be a combination of undocumented behavior and
- * firmware bugs in the H-P printers that make it difficult to determine
- * the proper interaction of character and page transformations.
- * The following two conditionals probably should not be enabled,
- * but we leave them here just in case this turns out to be wrong.
- */
-/*#define TRANSFORM_TEXT_AS_OBJECTS*/
-/*#define POST_TRANSFORM_CHARS*/
-
 /* ---------------- Initialization ---------------- */
 
 int
@@ -88,17 +78,6 @@ set_symbol_map(px_state_t *pxs)
 	  }
 }
 
-/* Recompute the combined character matrix from character and font */
-/* parameters.  Note that this depends on the current font. */
-private double
-adjust_scale(double scale)
-{	double int_scale = floor(scale + 0.5);
-	double diff = scale - int_scale;
-
-	/* If the scale is very close to an integer, make it integral, */
-	/* so we won't have to scale the bitmap (or can scale it fast). */
-	return (diff < 0.001 && diff > -0.001 ? int_scale : scale);
-}
 private int
 px_set_char_matrix(px_state_t *pxs)
 {	px_gstate_t *pxgs = pxs->pxgs;
@@ -121,10 +100,10 @@ px_set_char_matrix(px_state_t *pxs)
 	       )
 	      return_error(pxs->memory, errorIllegalFontData);
 	    gs_defaultmatrix(pxs->pgs, &mat);
-	    gs_make_scaling(
-	      adjust_scale(fabs(mat.xx + mat.yx) * 72 / pxfont->resolution.x),
-	      adjust_scale(fabs(mat.yy + mat.xy) * 72 / pxfont->resolution.y),
-	      &mat);
+	    
+	    /* remove negative scale component */
+	    gs_make_scaling( 1, 1, &mat );
+	    
 	    /*
 	     * Rotate the bitmap to undo the effect of its built-in
 	     * orientation and add the page orientation rotation
@@ -155,6 +134,10 @@ px_set_char_matrix(px_state_t *pxs)
 		  if ( pxgs->char_shear.x != 0 || pxgs->char_shear.y != 0 )
 		    { gs_matrix smat;
 		      gs_make_identity(&smat);
+		      if( pxgs->char_shear.x == 1 && pxgs->char_shear.y == 1) {
+			  /* make 1 1 shear matrix invertable pxlfts2.0/t310.bin */
+			  pxgs->char_shear.y += 0.0001;
+		      }
 		      smat.yx = pxgs->char_shear.x;
 		      smat.xy = pxgs->char_shear.y;
 		      gs_matrix_multiply(&smat, &mat, &mat);
@@ -178,8 +161,7 @@ px_set_char_matrix(px_state_t *pxs)
 /* This procedure implements FontHeader loading; it is exported for */
 /* initializing the error page font. */
 int
-px_define_font(px_font_t *pxfont, const byte *header, ulong size, gs_id id,
-  px_state_t *pxs)
+px_define_font(px_font_t *pxfont, byte *header, ulong size, gs_id id, px_state_t *pxs)
 {	gs_memory_t *mem = pxs->memory;
 	uint num_chars;
 
@@ -192,8 +174,9 @@ px_define_font(px_font_t *pxfont, const byte *header, ulong size, gs_id id,
 	     header[5] != 0 /* variety */
 	   )
 	  return_error(mem, errorIllegalFontHeaderFields);
+
 	pxfont->header = (byte *)header; /* remove const cast */
-	pxfont->header_size = size;
+ 	pxfont->header_size = size;
 	{ static const pl_font_offset_errors_t errors = {
 	    errorIllegalFontData,
 	    errorIllegalFontSegment,
@@ -253,6 +236,16 @@ px_define_font(px_font_t *pxfont, const byte *header, ulong size, gs_id id,
 	    pl_fill_in_tt_font(pfont, NULL, id);
 	  }
 	pxfont->params.symbol_set = pl_get_uint16(header + 2);
+
+        if ( header[4] == plfst_TrueType ) {
+            pxfont->is_xl_format = true;
+            pl_prepend_xl_dummy_header(mem, &header);
+            pxfont->header = header;
+            pxfont->header_size = gs_object_size(mem, header);
+        } else {
+            pxfont->is_xl_format = false;
+        }
+
 	return gs_definefont(pxs->font_dir, pxfont->pfont);
 }
 
@@ -280,7 +273,7 @@ private void
 px_str_to_gschars( px_args_t *par, px_state_t *pxs, gs_char *pchr)
 {
     const px_value_t *pstr = par->pv[0];
-    const char *str = (const char *)pstr->value.array.data;
+    const unsigned char *str = (const unsigned char *)pstr->value.array.data;
     uint len = pstr->value.array.size;
     int i;
     gs_char chr;
@@ -375,44 +368,8 @@ px_text(px_args_t *par, px_state_t *pxs, bool to_path)
 	return code;
     }
     gs_currentmatrix(pgs, &save_ctm);
-
-    if ( pxgs->base_font->scaling_technology == plfst_bitmap )
-    { /*
-       * Bitmap fonts don't scale or rotate: the char_matrix is the
-       * actual matrix to use, aside from translation.
-       */
-	gs_matrix mat;
-	mat = pxgs->char_matrix;
-	mat.tx = save_ctm.tx;
-	mat.ty = save_ctm.ty;
-	gs_setmatrix(pgs, &mat);
-    }
-    else
-#ifdef TRANSFORM_TEXT_AS_OBJECTS
-	/* Keep the current translation, but post-scale and rotate. */
-    { 
-	gs_matrix tmat, rmat;
-	tmat = pxs->initial_matrix;
-	gs_matrix_rotate(&tmat, 90 * (int)pxs->orientation, &tmat);
-	gs_matrix_multiply(&tmat, &pxgs->text_ctm, &tmat);
-	gs_make_rotation(-90 * (int)pxs->orientation, &rmat);
-	gs_matrix_multiply(&tmat, &rmat, &tmat);
-	tmat.tx = save_ctm.tx;
-	tmat.ty = save_ctm.ty;
-	gs_setmatrix(pgs, &tmat);
-    }
-#endif
-#ifdef POST_TRANSFORM_CHARS
-    {
-	gs_matrix cmat, mat;
-	gs_currentmatrix(pgs, &cmat);
-	gs_matrix_multiply(&cmat, &pxgs->char_matrix, &mat);
-	gs_setmatrix(pgs, &mat);
-    }
-#else
-
     gs_concat(pgs, &pxgs->char_matrix);
-#endif
+
     /* set the writing mode */
 	
     /* NB
@@ -616,6 +573,7 @@ px_text(px_args_t *par, px_state_t *pxs, bool to_path)
 		fvals[i*2] = font_distance.x;
 		fvals[i*2 +1] = font_distance.y;  
 
+
 	    }
 	    // NB: this looks correct but pdfwrite isn't generating 
 	    // the correct information for text selection to compute spaces correctly.
@@ -850,14 +808,16 @@ pxReadChar(px_args_t *par, px_state_t *pxs)
 	  }
 	/* We have the complete character. */
 	/* Do error checks before installing. */
-	{ const byte *header = pxs->download_font->header;
+	{ 
+            /* const byte *header = pxs->download_font->header;
+             see NB just below */
 	  const byte *data = pxs->download_bytes.data;
 	  int code = 0;
 
 	  switch ( data[0] )
 	    {
 	    case 0:		/* bitmap */
-	      if ( header[4] != plfst_bitmap )
+                if ( false /* NB FIXME header[4] != plfst_bitmap */)
 		code = gs_note_error(pxs->memory, errorFSTMismatch);
 	      else if ( data[1] != 0 )
 		code = gs_note_error(pxs->memory, errorUnsupportedCharacterClass);
@@ -868,7 +828,7 @@ pxReadChar(px_args_t *par, px_state_t *pxs)
 		code = gs_note_error(pxs->memory, errorIllegalCharacterData);
 	      break;
 	    case 1:		/* TrueType outline */
-	      if ( header[4] != plfst_TrueType )
+                if ( false /* NB FIXME header[4] != plfst_TrueType */ )
 		code = gs_note_error(pxs->memory, errorFSTMismatch);
 	      else if ( data[1] != 0 && data[1] != 1 
 			/* && data[1] != 2  NB Needs to be tested uncomment to try */ )
