@@ -9,7 +9,7 @@
    license.  Refer to licensing information at http://www.artifex.com/ or
    contact Artifex Software, Inc., 101 Lucas Valley Road #110,
    San Rafael, CA  94903, (415)492-9861, for further information. */
-/*$Id: pxgstate.c,v 1.27 2004/01/20 21:30:00 stefan Exp $ */
+/*$Id: pxgstate.c,v 1.33 2005/02/03 18:57:59 henrys Exp $ */
 
 /* pxgstate.c */
 /* PCL XL graphics state operators */
@@ -22,6 +22,7 @@
 #include "gsstruct.h"
 #include "pxoper.h"
 #include "pxstate.h"
+#include "pxparse.h"
 #include "gdebug.h"
 #include "gsstate.h"
 #include "gscoord.h"
@@ -34,6 +35,7 @@
 #include "gxpath.h"
 #include "gzstate.h"
 #include "gscolor2.h"
+#include "plsrgb.h"
 
 /*
  * There is an apparent bug in the LJ5 and LJ6MP firmware that causes
@@ -54,60 +56,6 @@ px_operator_proc(pxRectanglePath);
 /* Forward references */
 px_operator_proc(pxSetClipIntersect);
 
-/* GC descriptors */
-private_st_px_paint();
-#define ppt ((px_paint_t *)vptr)
-private ENUM_PTRS_BEGIN(px_paint_enum_ptrs) {
-    if ( ppt->type != pxpPattern )
-	return 0;
-    return ENUM_SUPER_ELT(px_paint_t, st_client_color,
-			  value.pattern.color, 1);
-}
-    case 0:
-	ENUM_RETURN((ppt->type == pxpPattern ? ppt->value.pattern.pattern : 0));
-ENUM_PTRS_END
-private RELOC_PTRS_BEGIN(px_paint_reloc_ptrs) {
-    if ( ppt->type == pxpPattern ) {
-	 RELOC_PTR(px_paint_t, value.pattern.pattern);
-	 RELOC_SUPER_ELT(px_paint_t, st_client_color, value.pattern.color);
-    }
-} RELOC_PTRS_END
-#undef ppt
-private_st_px_gstate();
-#define pxgs ((px_gstate_t *)vptr)
-private ENUM_PTRS_BEGIN(px_gstate_enum_ptrs) {
-	index -= px_gstate_num_ptrs + px_gstate_num_string_ptrs;
-	if ( index == 0 )
-	  ENUM_RETURN_CONST_STRING_PTR(px_gstate_t, palette);
-	index--;
-	if ( index < st_px_paint_max_ptrs )
-	  return ENUM_SUPER_ELT(px_gstate_t, st_px_paint, brush, 0);
-	index -= st_px_paint_max_ptrs;
-	if ( index < st_px_paint_max_ptrs )
-	  return ENUM_SUPER_ELT(px_gstate_t, st_px_paint, pen, 0);
-	index -= st_px_paint_max_ptrs;
-	return ENUM_SUPER_ELT(px_gstate_t, st_px_dict, temp_pattern_dict, 0);
-	}
-#define mp(i,e) ENUM_PTR(i, px_gstate_t, e);
-#define ms(i,e) ENUM_STRING_PTR(px_gstate_num_ptrs + i, px_gstate_t, e);
-	px_gstate_do_ptrs(mp)
-	px_gstate_do_string_ptrs(ms)
-#undef mp
-#undef ms
-ENUM_PTRS_END
-private RELOC_PTRS_BEGIN(px_gstate_reloc_ptrs) {
-	RELOC_SUPER_ELT(px_gstate_t, st_px_paint, brush);
-	RELOC_CONST_STRING_PTR(px_gstate_t, palette);
-	RELOC_SUPER_ELT(px_gstate_t, st_px_paint, pen);
-	RELOC_SUPER_ELT(px_gstate_t, st_px_dict, temp_pattern_dict);
-#define mp(i,e) RELOC_PTR(px_gstate_t, e);
-#define ms(i,e) RELOC_STRING_PTR(px_gstate_t, e);
-	px_gstate_do_ptrs(mp)
-	px_gstate_do_string_ptrs(ms)
-#undef mp
-#undef ms
-} RELOC_PTRS_END
-#undef pxgs
 
 /* Imported color space types */
 extern const gs_color_space_type gs_color_space_type_Indexed; /* gscolor2.c */
@@ -148,22 +96,25 @@ px_gstate_rc_adjust(px_gstate_t *pxgs, int delta, gs_memory_t *mem)
 }
 private void *
 px_gstate_client_alloc(gs_memory_t *mem)
-{	px_gstate_t *pxgs =
-	  gs_alloc_struct(mem, px_gstate_t, &st_px_gstate, "px_gstate_alloc");
+{	
+    px_gstate_t *pxgs = 
+        (px_gstate_t *)gs_alloc_bytes(mem, 
+                                      sizeof(px_gstate_t),
+                                      "px_gstate_alloc");
 
-	if ( pxgs == 0 )
-	  return 0;
-	/* Initialize reference-counted pointers and other pointers */
-	/* needed to establish invariants. */
-	pxgs->memory = mem;
-	pxgs->halftone.thresholds.data = 0;
-	pxgs->halftone.thresholds.size = 0;
-	pxgs->dither_matrix.data = 0;
-	pxgs->dither_matrix.size = 0;
-	pxgs->brush.type = pxpNull;
-	pxgs->pen.type = pxpNull;
-	px_dict_init(&pxgs->temp_pattern_dict, mem, px_free_pattern);
-	return pxgs;
+    if ( pxgs == 0 )
+        return 0;
+    /* Initialize reference-counted pointers and other pointers */
+    /* needed to establish invariants. */
+    pxgs->memory = mem;
+    pxgs->halftone.thresholds.data = 0;
+    pxgs->halftone.thresholds.size = 0;
+    pxgs->dither_matrix.data = 0;
+    pxgs->dither_matrix.size = 0;
+    pxgs->brush.type = pxpNull;
+    pxgs->pen.type = pxpNull;
+    px_dict_init(&pxgs->temp_pattern_dict, mem, px_free_pattern);
+    return pxgs;
 }
 private int
 px_gstate_client_copy_for(void *to, void *from, gs_state_copy_reason_t reason)
@@ -242,11 +193,11 @@ px_gstate_client_free(void *old, gs_memory_t *mem)
 
 	px_dict_release(&pxgs->temp_pattern_dict);
 	if ( pxgs->halftone.thresholds.data )
-	  gs_free_string(mem, pxgs->halftone.thresholds.data,
+            gs_free_string(mem, (byte *)pxgs->halftone.thresholds.data,
 			 pxgs->halftone.thresholds.size,
 			 "px_gstate_free(halftone.thresholds)");
 	if ( pxgs->dither_matrix.data )
-	  gs_free_string(mem, pxgs->dither_matrix.data,
+            gs_free_string(mem, (byte *)pxgs->dither_matrix.data,
 			 pxgs->dither_matrix.size,
 			 "px_gstate_free(dither_matrix)");
 	px_gstate_rc_adjust(old, -1, mem);
@@ -362,38 +313,45 @@ px_initclip(px_state_t *pxs)
 /* Set up the color space information for a bitmap image or pattern. */
 int
 px_image_color_space(gs_color_space *pcs, gs_image_t *pim,
-  const px_bitmap_params_t *params, const gs_const_string *palette,
+  const px_bitmap_params_t *params, const gs_string *palette,
   const gs_state *pgs)
 {	
 
     int depth = params->depth;
+    gs_color_space base_pcs;
+    gs_color_space *pbase_pcs;
+    bool cie_space = false;
     switch ( params->color_space ) {
     case eGray:
-	gs_cspace_init_DeviceGray(pgs->memory, pcs);
+	gs_cspace_init_DeviceGray(pgs->memory, &base_pcs);
 	break;
     case eRGB:
-        gs_cspace_init_DeviceRGB(pgs->memory, pcs);
+        gs_cspace_init_DeviceRGB(pgs->memory, &base_pcs);
         break;
     case eSRGB:
     case eCRGB:
-        // NB should check for code.
-        pl_cspace_init_SRGB(&pcs, pgs);
+        if ( pl_cspace_init_SRGB(&pbase_pcs, pgs) < 0 )
+            /* should not happen */
+            return_error(pgs->memory, errorInsufficientMemory);
+        cie_space = true;
 	break;
     default:
 	return_error(pgs->memory, errorIllegalAttributeValue);
     }
+
     if ( params->indexed ) { 
-	pcs->params.indexed.base_space.type = pcs->type;
+        memmove(&pcs->params.indexed.base_space, 
+                (cie_space ? pbase_pcs : &base_pcs),
+                sizeof(pcs->params.indexed.base_space));
+	gs_cspace_init(pcs, &gs_color_space_type_Indexed, pgs->memory);
 	pcs->params.indexed.hival = (1 << depth) - 1;
-	pcs->params.indexed.lookup.table = *palette;
+	pcs->params.indexed.lookup.table.data = palette->data;
+	pcs->params.indexed.lookup.table.size = palette->size;
 	pcs->params.indexed.use_proc = 0;
-	pcs->type = &gs_color_space_type_Indexed;
-    }
-    {
-        gs_color_space image_init_pcs;
-        gs_cspace_init_DeviceRGB(pgs->memory, &image_init_pcs);
-        gs_image_t_init(pim, &image_init_pcs);
+    } else {
+        *pcs = (cie_space ? *pbase_pcs : base_pcs);
     }
+    gs_image_t_init(pim, pcs);
     pim->ColorSpace = pcs;
     pim->BitsPerComponent = depth;
     if ( params->indexed )
@@ -436,7 +394,7 @@ pxPopGS(px_args_t *par, px_state_t *pxs)
 	if ( pxgs->stack_depth == 0 )
 	  return 0;
 	if ( pxgs->palette.data && !pxgs->palette_is_shared ) {
-	  gs_free_string(pxs->memory, pxgs->palette.data,
+            gs_free_string(pxs->memory, (byte *)pxgs->palette.data,
 			 pxgs->palette.size, "pxPopGS(palette)");
 	  pxgs->palette.data = 0;
 	}
@@ -462,12 +420,104 @@ pxPushGS(px_args_t *par, px_state_t *pxs)
 	return code;
 }
 
+/* To restore the interpreters to default state we assemble the
+   following pxl commands and execute them as a stream.
+
+ubyte 2 ColorSpace
+SetColorSpace
+
+ubyte_array [ uint16 3
+0000   00 00 00                                           ...
+] RGBColor
+SetBrushSource
+
+uint16 0 CharAngle
+SetCharAngle
+
+SetPageDefaultCTM
+ubyte_array [ uint16 3
+0000   00 00 00                                           ...
+
+] RGBColor
+SetPenSource
+
+ubyte 1 PenWidth
+SetPenWidth
+
+ubyte 0 TxMode
+SetSourceTxMode
+
+ubyte 0 TxMode
+SetPatternTxMode
+
+ubyte 252 ROP3
+SetROP
+
+ubyte 0 LineCapStyle
+SetLineCap
+
+ubyte 0 SolidLine
+SetLineDash
+
+ubyte 0 LineJoinStyle
+SetLineJoin
+
+uint16 10 MiterLength
+SetMiterLimit
+
+real32_xy 0.000000 0.000000 CharScale
+SetCharScale
+
+real32_xy 0.000000 0.000000 CharShear
+SetCharShear
+
+ubyte 0 DeviceMatrix
+SetHalftoneMethod
+
+ubyte 0 ClipMode
+SetClipMode
+
+SetClipToPage
+
+NewPath
+
+ubyte 0 FillMode
+SetFillMode
+
+*/
+
+/* assembled (little endian) stream */
+private const byte pxSetDefaultGSstr[] = {
+    192,2,248,3,106,200,193,3,0,0,0,0,248,11,99,193,
+    0,0,248,161,100,116,200,193,3,0,0,0,0,248,11,121,192,1,248,75,122,192,
+    0,248,45,124,192,0,248,45,120,192,252,248,44,123,192,0,248,71,113,192,
+    0,248,78,112,192,0,248,72,114,193,10,0,248,73,115,213,0,0,0,0,0,0,0,0,
+    248,164,101,213,0,0,0,0,0,0,0,0,248,165,102,192,0,248,33,109,192,0,248,
+    84,127,105,133,192,0,248,70,110
+};
+
+
 const byte apxSetDefaultGS[] = {0, 0};
 int
 pxSetDefaultGS(px_args_t *par, px_state_t *pxs)
 {
-    px_gstate_reset(pxs->pxgs);
-    return 0;
+    px_parser_state_t *pst = par->parser;
+    px_parser_state_t st;
+    stream_cursor_read r;
+    int code;
+
+    st.memory = pxs->memory;
+    px_process_init(&st, false /* big_endian */);
+
+    st.macro_state = pst->macro_state | ptsExecStream;
+    r.ptr = pxSetDefaultGSstr - 1;
+    r.limit = r.ptr + sizeof(pxSetDefaultGSstr);
+
+    /* we don't expect this to fail */
+    code = px_process(&st, pxs, &r);
+
+    pst->macro_state = st.macro_state & ~ptsExecStream;
+    return code;
 }
 
 const byte apxSetClipReplace[] = {
