@@ -9,7 +9,7 @@
    license.  Refer to licensing information at http://www.artifex.com/ or
    contact Artifex Software, Inc., 101 Lucas Valley Road #110,
    San Rafael, CA  94903, (415)492-9861, for further information. */
-/*$Id: pximage.c,v 1.17 2003/11/19 22:29:19 stefan Exp $ */
+/*$Id: pximage.c,v 1.20 2004/12/30 22:03:08 henrys Exp $ */
 
 /* pximage.c */
 /* PCL XL bitmap painting operators */
@@ -41,23 +41,11 @@
 #include "strimpl.h"
 #include "srlx.h"
 #include "pldraw.h"
+#include "plsrgb.h"
 #include "jpeglib_.h"           /* for jpeg filter */
 #include "sdct.h"
 #include "sjpeg.h"
 
-/* GC descriptors */
-private_st_px_pattern();
-#define ppat ((px_pattern_t *)vptr)
-private ENUM_PTRS_BEGIN(px_pattern_enum_ptrs) return 0;
-	ENUM_CONST_STRING_PTR(0, px_pattern_t, palette);
-	ENUM_PTR(1, px_pattern_t, data);
-ENUM_PTRS_END
-private RELOC_PTRS_BEGIN(px_pattern_reloc_ptrs) {
-	RELOC_CONST_STRING_PTR(px_pattern_t, palette);
-	RELOC_PTR(px_pattern_t, data);
-} RELOC_PTRS_END
-#undef ppat
-
 /* Define the "freeing" procedure for patterns in a dictionary. */
 void
 px_free_pattern(gs_memory_t *mem, void *vptr, client_name_t cname)
@@ -552,8 +540,12 @@ pxBeginImage(px_args_t *par, px_state_t *pxs)
 	 */
 	if ( pxs->pxgs->brush.type == pxpNull &&
 	     !rop3_uses_T(gs_currentrasterop(pgs))
-	   )
-	  code = gs_setgray(pgs, 0.0);
+             ) {
+            if ( pxs->useciecolor )
+                code = pl_setSRGB(pgs, 0.0, 0.0, 0.0);
+            else
+                code = gs_setgray(pgs, 0.0);
+        }
 	else
 	  code = px_set_paint(&pxgs->brush, pxs);
 	if ( code < 0 )
@@ -581,7 +573,7 @@ pxBeginImage(px_args_t *par, px_state_t *pxs)
 	    code = gs_note_error(pxs->memory, errorInsufficientMemory);
 	  else 
 	    code = px_image_color_space(&pxenum->color_space, &pxenum->image,
-					&params, &pxgs->palette, pgs);
+					&params, (const gs_string *)&pxgs->palette, pgs);
 	}
 	if ( code < 0 )
 	  { gs_free_object(pxs->memory, pxenum->row, "pxReadImage(row)");
@@ -688,6 +680,8 @@ pxBeginRastPattern(px_args_t *par, px_state_t *pxs)
 	uint psize;
 	byte *pdata;
 	int code = begin_bitmap(&params, &benum, par, pxs);
+        private const gs_memory_struct_type_t st_px_pattern = 
+            {sizeof(px_pattern_t), "", 0, 0, 0, 0, 0};
 
 	if ( code < 0 )
 	  return code;
