@@ -9,7 +9,7 @@
    license.  Refer to licensing information at http://www.artifex.com/ or
    contact Artifex Software, Inc., 101 Lucas Valley Road #110,
    San Rafael, CA  94903, (415)492-9861, for further information. */
-/*$Id: pxparse.c,v 1.8 2003/09/06 17:11:39 stefan Exp $ */
+/*$Id: pxparse.c,v 1.10 2005/02/24 16:56:48 stefan Exp $ */
 
 /* pxparse.c */
 /* PCL XL parser */
@@ -527,7 +527,11 @@ top:	if ( st->data_left )
 	      case 4:
 		switch ( tag )
 		  {
-		  case pxtSpace: continue;
+		  case pxtSpace:
+		      /* break; will error, compatible with lj */
+		      /* ++p;continue; silently ignores the space */
+		      ++p; 
+		      continue;
 		  default: break;
 		  }
 		break;
@@ -795,7 +799,7 @@ a:		      if ( attr >= px_attribute_next )
 			    &st->stack[st->attribute_indices[attr]];
 			  /* If the old value is on the heap, free it. */
 			  if ( old_sp->type & pxd_on_heap )
-			    gs_free_object(memory, old_sp->value.array.data,
+                              gs_free_object(memory, (void *)old_sp->value.array.data,
 					   "old value for duplicate attribute");
 			  *old_sp = *sp--;
 			}
