@@ -9,7 +9,7 @@
    license.  Refer to licensing information at http://www.artifex.com/ or
    contact Artifex Software, Inc., 101 Lucas Valley Road #110,
    San Rafael, CA  94903, (415)492-9861, for further information. */
-/*$Id: pxsessio.c,v 1.26 2003/09/06 17:11:39 stefan Exp $ */
+/*$Id: pxsessio.c,v 1.30 2005/02/08 18:59:53 henrys Exp $ */
 
 /* pxsessio.c */
 /* PCL XL session operators */
@@ -29,10 +29,14 @@
 #include "gsstate.h"
 #include "gxfixed.h"
 #include "gxpath.h"             /* for gx_clip_to_rectangle */
+#include "gxdcolor.h"
+#include "gxpcolor.h"
 #include "gxfcache.h"
 #include "gxdevice.h"
+#include "gxstate.h"
 #include "pjtop.h"
 #include "pllfont.h"
+#include "plsrgb.h"
 
 /* Imported operators */
 px_operator_proc(pxCloseDataSource);
@@ -175,7 +179,7 @@ px_end_page_cleanup(px_state_t *pxs)
 
 /* Purge all */
 private bool
-purge_all(cached_char *cc, void *dummy)
+purge_all(const gs_memory_t *mem, cached_char *cc, void *dummy)
 {	
     return true;
 }
@@ -188,12 +192,29 @@ px_end_session_cleanup(px_state_t *pxs)
 	  pxCloseDataSource(NULL, pxs);
 	px_purge_character_cache(pxs);
 	px_dict_release(&pxs->session_pattern_dict);
-	px_purge_pattern_cache(pxs, eSessionPattern);
+        if (gstate_pattern_cache(pxs->pgs)) {
+            (gstate_pattern_cache(pxs->pgs)->free_all)
+                (gstate_pattern_cache(pxs->pgs));
+            gs_free_object(pxs->memory,
+                           gstate_pattern_cache(pxs->pgs)->tiles,
+                           "px_end_session_cleanup(tiles)");
+            gs_free_object(pxs->memory,
+                           gstate_pattern_cache(pxs->pgs),
+                           "px_end_session_cleanup(struct)");
+            {
+                gs_state *pgs = pxs->pgs;
+                while (pgs) {
+                    gstate_set_pattern_cache(pgs, 0);
+                    pgs = gs_state_saved(pgs);
+                }
+            }
+        }
 	/* We believe that streams do *not* persist across sessions.... */
 	px_dict_release(&pxs->stream_dict);
 	/* delete downloaded fonts on end of session */
 	px_dict_release(&pxs->font_dict);
-        pl_free_crd(pxs->pgs);
+        pl_free_srgb(pxs->pgs);
+        pxpcl_release();
 }
 
 /* ---------------- Non-operator procedures ---------------- */
